@@ -58,10 +58,10 @@ void WiredConnectionWidget::loadConfig(const NetworkManager::Setting::Ptr &setti
 {
     NetworkManager::WiredSetting::Ptr wiredSetting = setting.staticCast<NetworkManager::WiredSetting>();
 
-    m_widget->macAddress->init(NetworkManager::Device::Ethernet, NetworkManager::Utils::macAddressAsString(wiredSetting->macAddress()));
+    m_widget->macAddress->init(NetworkManager::Device::Ethernet, NetworkManager::macAddressAsString(wiredSetting->macAddress()));
 
     if (!wiredSetting->clonedMacAddress().isEmpty()) {
-        m_widget->clonedMacAddress->setText(NetworkManager::Utils::macAddressAsString(wiredSetting->clonedMacAddress()));
+        m_widget->clonedMacAddress->setText(NetworkManager::macAddressAsString(wiredSetting->clonedMacAddress()));
     }
 
     if (wiredSetting->mtu()) {
@@ -87,10 +87,10 @@ QVariantMap WiredConnectionWidget::setting(bool agentOwned) const
 
     NetworkManager::WiredSetting wiredSetting;
 
-    wiredSetting.setMacAddress(NetworkManager::Utils::macAddressFromString(m_widget->macAddress->hwAddress()));
+    wiredSetting.setMacAddress(NetworkManager::macAddressFromString(m_widget->macAddress->hwAddress()));
 
     if (!m_widget->clonedMacAddress->text().isEmpty() && m_widget->clonedMacAddress->text() != ":::::") {
-        wiredSetting.setClonedMacAddress(NetworkManager::Utils::macAddressFromString(m_widget->clonedMacAddress->text()));
+        wiredSetting.setClonedMacAddress(NetworkManager::macAddressFromString(m_widget->clonedMacAddress->text()));
     }
 
     if (m_widget->mtu->value()) {
@@ -124,7 +124,7 @@ void WiredConnectionWidget::generateRandomClonedMac()
         int random = qrand() % 255;
         mac[i] = random;
     }
-    m_widget->clonedMacAddress->setText(NetworkManager::Utils::macAddressAsString(mac));
+    m_widget->clonedMacAddress->setText(NetworkManager::macAddressAsString(mac));
 }
 
 bool WiredConnectionWidget::isValid() const
@@ -134,7 +134,7 @@ bool WiredConnectionWidget::isValid() const
     }
 
     if (m_widget->clonedMacAddress->text() != ":::::") {
-        if (!NetworkManager::Utils::macAddressIsValid(m_widget->clonedMacAddress->text())) {
+        if (!NetworkManager::macAddressIsValid(m_widget->clonedMacAddress->text())) {
             return false;
         }
     }
