@@ -512,32 +512,32 @@ NetworkManager::ModemDevice::Capability UiUtils::modemSubType(NetworkManager::Mo
     return NetworkManager::ModemDevice::NoCapability;
 }
 
-QString UiUtils::labelFromWirelessSecurity(NetworkManager::Utils::WirelessSecurityType type)
+QString UiUtils::labelFromWirelessSecurity(NetworkManager::WirelessSecurityType type)
 {
     QString tip;
     switch (type) {
-        case NetworkManager::Utils::None:
+        case NetworkManager::NoneSecurity:
             tip = i18nc("@label no security", "Insecure");
             break;
-        case NetworkManager::Utils::StaticWep:
+        case NetworkManager::StaticWep:
             tip = i18nc("@label WEP security", "WEP");
             break;
-        case NetworkManager::Utils::Leap:
+        case NetworkManager::Leap:
             tip = i18nc("@label LEAP security", "LEAP");
             break;
-        case NetworkManager::Utils::DynamicWep:
+        case NetworkManager::DynamicWep:
             tip = i18nc("@label Dynamic WEP security", "Dynamic WEP");
             break;
-        case NetworkManager::Utils::WpaPsk:
+        case NetworkManager::WpaPsk:
             tip = i18nc("@label WPA-PSK security", "WPA-PSK");
             break;
-        case NetworkManager::Utils::WpaEap:
+        case NetworkManager::WpaEap:
             tip = i18nc("@label WPA-EAP security", "WPA-EAP");
             break;
-        case NetworkManager::Utils::Wpa2Psk:
+        case NetworkManager::Wpa2Psk:
             tip = i18nc("@label WPA2-PSK security", "WPA2-PSK");
             break;
-        case NetworkManager::Utils::Wpa2Eap:
+        case NetworkManager::Wpa2Eap:
             tip = i18nc("@label WPA2-EAP security", "WPA2-EAP");
             break;
         default:
