@@ -38,7 +38,7 @@ public:
     virtual void readSecrets();
     virtual QVariantMap setting(bool agentOwned = false) const;
 
-private slots:
+private Q_SLOTS:
     void showPasswordsChanged(bool);
 
 private:
